/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.Timer.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "timeradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class TimerAdaptor
 */

TimerAdaptor::TimerAdaptor(Timer *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

TimerAdaptor::~TimerAdaptor()
{
    // destructor
}

QString TimerAdaptor::commandTimeout() const
{
    // get the value of property commandTimeout
    return qvariant_cast< QString >(parent()->property("commandTimeout"));
}

void TimerAdaptor::setCommandTimeout(const QString &value)
{
    // set the value of property commandTimeout
    parent()->setProperty("commandTimeout", QVariant::fromValue(value));
}

QString TimerAdaptor::label() const
{
    // get the value of property label
    return qvariant_cast< QString >(parent()->property("label"));
}

void TimerAdaptor::setLabel(const QString &value)
{
    // set the value of property label
    parent()->setProperty("label", QVariant::fromValue(value));
}

int TimerAdaptor::length() const
{
    // get the value of property length
    return qvariant_cast< int >(parent()->property("length"));
}

void TimerAdaptor::setLength(int value)
{
    // set the value of property length
    parent()->setProperty("length", QVariant::fromValue(value));
}

bool TimerAdaptor::looping() const
{
    // get the value of property looping
    return qvariant_cast< bool >(parent()->property("looping"));
}

void TimerAdaptor::setLooping(bool value)
{
    // set the value of property looping
    parent()->setProperty("looping", QVariant::fromValue(value));
}

bool TimerAdaptor::ringing() const
{
    // get the value of property ringing
    return qvariant_cast< bool >(parent()->property("ringing"));
}

bool TimerAdaptor::running() const
{
    // get the value of property running
    return qvariant_cast< bool >(parent()->property("running"));
}

int TimerAdaptor::timeCompleted() const
{
    // get the value of property timeCompleted
    return qvariant_cast< int >(parent()->property("timeCompleted"));
}

void TimerAdaptor::dismiss()
{
    // handle method call org.kde.kclock.Timer.dismiss
    parent()->dismiss();
}

int TimerAdaptor::elapsed()
{
    // handle method call org.kde.kclock.Timer.elapsed
    return parent()->elapsed();
}

void TimerAdaptor::reset()
{
    // handle method call org.kde.kclock.Timer.reset
    parent()->reset();
}

int TimerAdaptor::timeCompleted()
{
    // handle method call org.kde.kclock.Timer.timeCompleted
    return parent()->timeCompleted();
}

void TimerAdaptor::toggleLooping()
{
    // handle method call org.kde.kclock.Timer.toggleLooping
    parent()->toggleLooping();
}

void TimerAdaptor::toggleRunning()
{
    // handle method call org.kde.kclock.Timer.toggleRunning
    parent()->toggleRunning();
}

QString TimerAdaptor::uuid()
{
    // handle method call org.kde.kclock.Timer.uuid
    return parent()->uuid();
}


#include "moc_timeradaptor.cpp"
