/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.Alarm.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "alarmadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class AlarmAdaptor
 */

AlarmAdaptor::AlarmAdaptor(Alarm *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

AlarmAdaptor::~AlarmAdaptor()
{
    // destructor
}

QString AlarmAdaptor::audioPath() const
{
    // get the value of property audioPath
    return qvariant_cast< QString >(parent()->property("audioPath"));
}

void AlarmAdaptor::setAudioPath(const QString &value)
{
    // set the value of property audioPath
    parent()->setProperty("audioPath", QVariant::fromValue(value));
}

int AlarmAdaptor::daysOfWeek() const
{
    // get the value of property daysOfWeek
    return qvariant_cast< int >(parent()->property("daysOfWeek"));
}

void AlarmAdaptor::setDaysOfWeek(int value)
{
    // set the value of property daysOfWeek
    parent()->setProperty("daysOfWeek", QVariant::fromValue(value));
}

bool AlarmAdaptor::enabled() const
{
    // get the value of property enabled
    return qvariant_cast< bool >(parent()->property("enabled"));
}

void AlarmAdaptor::setEnabled(bool value)
{
    // set the value of property enabled
    parent()->setProperty("enabled", QVariant::fromValue(value));
}

int AlarmAdaptor::hours() const
{
    // get the value of property hours
    return qvariant_cast< int >(parent()->property("hours"));
}

void AlarmAdaptor::setHours(int value)
{
    // set the value of property hours
    parent()->setProperty("hours", QVariant::fromValue(value));
}

int AlarmAdaptor::minutes() const
{
    // get the value of property minutes
    return qvariant_cast< int >(parent()->property("minutes"));
}

void AlarmAdaptor::setMinutes(int value)
{
    // set the value of property minutes
    parent()->setProperty("minutes", QVariant::fromValue(value));
}

QString AlarmAdaptor::name() const
{
    // get the value of property name
    return qvariant_cast< QString >(parent()->property("name"));
}

void AlarmAdaptor::setName(const QString &value)
{
    // set the value of property name
    parent()->setProperty("name", QVariant::fromValue(value));
}

qulonglong AlarmAdaptor::nextRingTime() const
{
    // get the value of property nextRingTime
    return qvariant_cast< qulonglong >(parent()->property("nextRingTime"));
}

int AlarmAdaptor::ringDuration() const
{
    // get the value of property ringDuration
    return qvariant_cast< int >(parent()->property("ringDuration"));
}

void AlarmAdaptor::setRingDuration(int value)
{
    // set the value of property ringDuration
    parent()->setProperty("ringDuration", QVariant::fromValue(value));
}

bool AlarmAdaptor::ringing() const
{
    // get the value of property ringing
    return qvariant_cast< bool >(parent()->property("ringing"));
}

int AlarmAdaptor::snoozeDuration() const
{
    // get the value of property snoozeDuration
    return qvariant_cast< int >(parent()->property("snoozeDuration"));
}

void AlarmAdaptor::setSnoozeDuration(int value)
{
    // set the value of property snoozeDuration
    parent()->setProperty("snoozeDuration", QVariant::fromValue(value));
}

int AlarmAdaptor::snoozedLength() const
{
    // get the value of property snoozedLength
    return qvariant_cast< int >(parent()->property("snoozedLength"));
}

void AlarmAdaptor::dismiss()
{
    // handle method call org.kde.kclock.Alarm.dismiss
    parent()->dismiss();
}

void AlarmAdaptor::save()
{
    // handle method call org.kde.kclock.Alarm.save
    parent()->save();
}

void AlarmAdaptor::snooze()
{
    // handle method call org.kde.kclock.Alarm.snooze
    parent()->snooze();
}

QString AlarmAdaptor::uuid()
{
    // handle method call org.kde.kclock.Alarm.uuid
    return parent()->uuid();
}


#include "moc_alarmadaptor.cpp"
