/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.Alarm.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ALARMINTERFACE_H
#define ALARMINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.kclock.Alarm
 */
class OrgKdeKclockAlarmInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.kclock.Alarm"; }

public:
    OrgKdeKclockAlarmInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKclockAlarmInterface();

    Q_PROPERTY(QString audioPath READ audioPath WRITE setAudioPath)
    inline QString audioPath() const
    { return qvariant_cast< QString >(property("audioPath")); }
    inline void setAudioPath(const QString &value)
    { setProperty("audioPath", QVariant::fromValue(value)); }

    Q_PROPERTY(int daysOfWeek READ daysOfWeek WRITE setDaysOfWeek)
    inline int daysOfWeek() const
    { return qvariant_cast< int >(property("daysOfWeek")); }
    inline void setDaysOfWeek(int value)
    { setProperty("daysOfWeek", QVariant::fromValue(value)); }

    Q_PROPERTY(bool enabled READ enabled WRITE setEnabled)
    inline bool enabled() const
    { return qvariant_cast< bool >(property("enabled")); }
    inline void setEnabled(bool value)
    { setProperty("enabled", QVariant::fromValue(value)); }

    Q_PROPERTY(int hours READ hours WRITE setHours)
    inline int hours() const
    { return qvariant_cast< int >(property("hours")); }
    inline void setHours(int value)
    { setProperty("hours", QVariant::fromValue(value)); }

    Q_PROPERTY(int minutes READ minutes WRITE setMinutes)
    inline int minutes() const
    { return qvariant_cast< int >(property("minutes")); }
    inline void setMinutes(int value)
    { setProperty("minutes", QVariant::fromValue(value)); }

    Q_PROPERTY(QString name READ name WRITE setName)
    inline QString name() const
    { return qvariant_cast< QString >(property("name")); }
    inline void setName(const QString &value)
    { setProperty("name", QVariant::fromValue(value)); }

    Q_PROPERTY(qulonglong nextRingTime READ nextRingTime)
    inline qulonglong nextRingTime() const
    { return qvariant_cast< qulonglong >(property("nextRingTime")); }

    Q_PROPERTY(int ringDuration READ ringDuration WRITE setRingDuration)
    inline int ringDuration() const
    { return qvariant_cast< int >(property("ringDuration")); }
    inline void setRingDuration(int value)
    { setProperty("ringDuration", QVariant::fromValue(value)); }

    Q_PROPERTY(bool ringing READ ringing)
    inline bool ringing() const
    { return qvariant_cast< bool >(property("ringing")); }

    Q_PROPERTY(int snoozeDuration READ snoozeDuration WRITE setSnoozeDuration)
    inline int snoozeDuration() const
    { return qvariant_cast< int >(property("snoozeDuration")); }
    inline void setSnoozeDuration(int value)
    { setProperty("snoozeDuration", QVariant::fromValue(value)); }

    Q_PROPERTY(int snoozedLength READ snoozedLength)
    inline int snoozedLength() const
    { return qvariant_cast< int >(property("snoozedLength")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> dismiss()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("dismiss"), argumentList);
    }

    inline QDBusPendingReply<> save()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("save"), argumentList);
    }

    inline QDBusPendingReply<> snooze()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("snooze"), argumentList);
    }

    inline QDBusPendingReply<QString> uuid()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("uuid"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void audioPathChanged();
    void daysOfWeekChanged();
    void enabledChanged();
    void hoursChanged();
    void minutesChanged();
    void nameChanged();
    void nextRingTimeChanged();
    void rescheduleRequested();
    void ringDurationChanged();
    void ringingChanged();
    void snoozeDurationChanged();
    void snoozedLengthChanged();
};

namespace org {
  namespace kde {
    namespace kclock {
      using Alarm = ::OrgKdeKclockAlarmInterface;
    }
  }
}

#endif
