/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.TimerModel.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "timermodeladaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class TimerModelAdaptor
 */

TimerModelAdaptor::TimerModelAdaptor(TimerModel *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

TimerModelAdaptor::~TimerModelAdaptor()
{
    // destructor
}

QString TimerModelAdaptor::defaultAudioLocation() const
{
    // get the value of property defaultAudioLocation
    return qvariant_cast< QString >(parent()->property("defaultAudioLocation"));
}

void TimerModelAdaptor::setDefaultAudioLocation(const QString &value)
{
    // set the value of property defaultAudioLocation
    parent()->setProperty("defaultAudioLocation", QVariant::fromValue(value));
}

void TimerModelAdaptor::addTimer(int length, const QString &label, bool looping, const QString &commandTimeout, bool running)
{
    // handle method call org.kde.kclock.TimerModel.addTimer
    parent()->addTimer(length, label, looping, commandTimeout, running);
}

void TimerModelAdaptor::removeTimer(const QString &uuid)
{
    // handle method call org.kde.kclock.TimerModel.removeTimer
    parent()->removeTimer(uuid);
}

QStringList TimerModelAdaptor::timers()
{
    // handle method call org.kde.kclock.TimerModel.timers
    return parent()->timers();
}


#include "moc_timermodeladaptor.cpp"
