/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.Alarm.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef ALARMADAPTOR_H
#define ALARMADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "alarm.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kclock.Alarm
 */
class AlarmAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kclock.Alarm")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kclock.Alarm\">\n"
"    <property access=\"readwrite\" type=\"s\" name=\"name\"/>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"enabled\"/>\n"
"    <property access=\"readwrite\" type=\"i\" name=\"hours\"/>\n"
"    <property access=\"readwrite\" type=\"i\" name=\"minutes\"/>\n"
"    <property access=\"readwrite\" type=\"i\" name=\"daysOfWeek\"/>\n"
"    <property access=\"readwrite\" type=\"s\" name=\"audioPath\"/>\n"
"    <property access=\"readwrite\" type=\"i\" name=\"ringDuration\"/>\n"
"    <property access=\"readwrite\" type=\"i\" name=\"snoozeDuration\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"snoozedLength\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"ringing\"/>\n"
"    <property access=\"read\" type=\"t\" name=\"nextRingTime\"/>\n"
"    <signal name=\"nameChanged\"/>\n"
"    <signal name=\"enabledChanged\"/>\n"
"    <signal name=\"hoursChanged\"/>\n"
"    <signal name=\"minutesChanged\"/>\n"
"    <signal name=\"daysOfWeekChanged\"/>\n"
"    <signal name=\"audioPathChanged\"/>\n"
"    <signal name=\"ringDurationChanged\"/>\n"
"    <signal name=\"snoozeDurationChanged\"/>\n"
"    <signal name=\"snoozedLengthChanged\"/>\n"
"    <signal name=\"ringingChanged\"/>\n"
"    <signal name=\"nextRingTimeChanged\"/>\n"
"    <signal name=\"rescheduleRequested\"/>\n"
"    <method name=\"dismiss\"/>\n"
"    <method name=\"snooze\"/>\n"
"    <method name=\"save\"/>\n"
"    <method name=\"uuid\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    AlarmAdaptor(Alarm *parent);
    ~AlarmAdaptor() override;

    inline Alarm *parent() const
    { return static_cast<Alarm *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QString audioPath READ audioPath WRITE setAudioPath)
    QString audioPath() const;
    void setAudioPath(const QString &value);

    Q_PROPERTY(int daysOfWeek READ daysOfWeek WRITE setDaysOfWeek)
    int daysOfWeek() const;
    void setDaysOfWeek(int value);

    Q_PROPERTY(bool enabled READ enabled WRITE setEnabled)
    bool enabled() const;
    void setEnabled(bool value);

    Q_PROPERTY(int hours READ hours WRITE setHours)
    int hours() const;
    void setHours(int value);

    Q_PROPERTY(int minutes READ minutes WRITE setMinutes)
    int minutes() const;
    void setMinutes(int value);

    Q_PROPERTY(QString name READ name WRITE setName)
    QString name() const;
    void setName(const QString &value);

    Q_PROPERTY(qulonglong nextRingTime READ nextRingTime)
    qulonglong nextRingTime() const;

    Q_PROPERTY(int ringDuration READ ringDuration WRITE setRingDuration)
    int ringDuration() const;
    void setRingDuration(int value);

    Q_PROPERTY(bool ringing READ ringing)
    bool ringing() const;

    Q_PROPERTY(int snoozeDuration READ snoozeDuration WRITE setSnoozeDuration)
    int snoozeDuration() const;
    void setSnoozeDuration(int value);

    Q_PROPERTY(int snoozedLength READ snoozedLength)
    int snoozedLength() const;

public Q_SLOTS: // METHODS
    void dismiss();
    void save();
    void snooze();
    QString uuid();
Q_SIGNALS: // SIGNALS
    void audioPathChanged();
    void daysOfWeekChanged();
    void enabledChanged();
    void hoursChanged();
    void minutesChanged();
    void nameChanged();
    void nextRingTimeChanged();
    void rescheduleRequested();
    void ringDurationChanged();
    void ringingChanged();
    void snoozeDurationChanged();
    void snoozedLengthChanged();
};

#endif
