/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.KClockSettings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kclocksettingsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KClockSettingsAdaptor
 */

KClockSettingsAdaptor::KClockSettingsAdaptor(KClockSettings *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KClockSettingsAdaptor::~KClockSettingsAdaptor()
{
    // destructor
}

QString KClockSettingsAdaptor::defaultTimeFormatValue() const
{
    // get the value of property defaultTimeFormatValue
    return qvariant_cast< QString >(parent()->property("defaultTimeFormatValue"));
}

int KClockSettingsAdaptor::defaultTimerNotificationValue() const
{
    // get the value of property defaultTimerNotificationValue
    return qvariant_cast< int >(parent()->property("defaultTimerNotificationValue"));
}

bool KClockSettingsAdaptor::isTimeFormatImmutable() const
{
    // get the value of property isTimeFormatImmutable
    return qvariant_cast< bool >(parent()->property("isTimeFormatImmutable"));
}

bool KClockSettingsAdaptor::isTimerNotificationImmutable() const
{
    // get the value of property isTimerNotificationImmutable
    return qvariant_cast< bool >(parent()->property("isTimerNotificationImmutable"));
}

QString KClockSettingsAdaptor::timeFormat() const
{
    // get the value of property timeFormat
    return qvariant_cast< QString >(parent()->property("timeFormat"));
}

void KClockSettingsAdaptor::setTimeFormat(const QString &value)
{
    // set the value of property timeFormat
    parent()->setProperty("timeFormat", QVariant::fromValue(value));
}

int KClockSettingsAdaptor::timerNotification() const
{
    // get the value of property timerNotification
    return qvariant_cast< int >(parent()->property("timerNotification"));
}

void KClockSettingsAdaptor::setTimerNotification(int value)
{
    // set the value of property timerNotification
    parent()->setProperty("timerNotification", QVariant::fromValue(value));
}


#include "moc_kclocksettingsadaptor.cpp"
