/****************************************************************************
** Meta object code from reading C++ file 'alarminterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "alarminterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'alarminterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26OrgKdeKclockAlarmInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeKclockAlarmInterface::qt_create_metaobjectdata<qt_meta_tag_ZN26OrgKdeKclockAlarmInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeKclockAlarmInterface",
        "audioPathChanged",
        "",
        "daysOfWeekChanged",
        "enabledChanged",
        "hoursChanged",
        "minutesChanged",
        "nameChanged",
        "nextRingTimeChanged",
        "rescheduleRequested",
        "ringDurationChanged",
        "ringingChanged",
        "snoozeDurationChanged",
        "snoozedLengthChanged",
        "dismiss",
        "QDBusPendingReply<>",
        "save",
        "snooze",
        "uuid",
        "QDBusPendingReply<QString>",
        "audioPath",
        "daysOfWeek",
        "enabled",
        "hours",
        "minutes",
        "name",
        "nextRingTime",
        "ringDuration",
        "ringing",
        "snoozeDuration",
        "snoozedLength"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'audioPathChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'daysOfWeekChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoursChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minutesChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextRingTimeChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rescheduleRequested'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ringDurationChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ringingChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'snoozeDurationChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'snoozedLengthChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'dismiss'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(14, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'save'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(16, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'snooze'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(17, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'uuid'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(18, 2, QMC::AccessPublic, 0x80000000 | 19),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'audioPath'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'daysOfWeek'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hours'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'minutes'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'nextRingTime'
        QtMocHelpers::PropertyData<qulonglong>(26, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'ringDuration'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'ringing'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'snoozeDuration'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'snoozedLength'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeKclockAlarmInterface, qt_meta_tag_ZN26OrgKdeKclockAlarmInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeKclockAlarmInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26OrgKdeKclockAlarmInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26OrgKdeKclockAlarmInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26OrgKdeKclockAlarmInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeKclockAlarmInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeKclockAlarmInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->audioPathChanged(); break;
        case 1: _t->daysOfWeekChanged(); break;
        case 2: _t->enabledChanged(); break;
        case 3: _t->hoursChanged(); break;
        case 4: _t->minutesChanged(); break;
        case 5: _t->nameChanged(); break;
        case 6: _t->nextRingTimeChanged(); break;
        case 7: _t->rescheduleRequested(); break;
        case 8: _t->ringDurationChanged(); break;
        case 9: _t->ringingChanged(); break;
        case 10: _t->snoozeDurationChanged(); break;
        case 11: _t->snoozedLengthChanged(); break;
        case 12: { QDBusPendingReply<> _r = _t->dismiss();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->save();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<> _r = _t->snooze();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<QString> _r = _t->uuid();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKclockAlarmInterface::*)()>(_a, &OrgKdeKclockAlarmInterface::audioPathChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKclockAlarmInterface::*)()>(_a, &OrgKdeKclockAlarmInterface::daysOfWeekChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKclockAlarmInterface::*)()>(_a, &OrgKdeKclockAlarmInterface::enabledChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKclockAlarmInterface::*)()>(_a, &OrgKdeKclockAlarmInterface::hoursChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKclockAlarmInterface::*)()>(_a, &OrgKdeKclockAlarmInterface::minutesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKclockAlarmInterface::*)()>(_a, &OrgKdeKclockAlarmInterface::nameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKclockAlarmInterface::*)()>(_a, &OrgKdeKclockAlarmInterface::nextRingTimeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKclockAlarmInterface::*)()>(_a, &OrgKdeKclockAlarmInterface::rescheduleRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKclockAlarmInterface::*)()>(_a, &OrgKdeKclockAlarmInterface::ringDurationChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKclockAlarmInterface::*)()>(_a, &OrgKdeKclockAlarmInterface::ringingChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKclockAlarmInterface::*)()>(_a, &OrgKdeKclockAlarmInterface::snoozeDurationChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKclockAlarmInterface::*)()>(_a, &OrgKdeKclockAlarmInterface::snoozedLengthChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->audioPath(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->daysOfWeek(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->hours(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->minutes(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 6: *reinterpret_cast<qulonglong*>(_v) = _t->nextRingTime(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->ringDuration(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->ringing(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->snoozeDuration(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->snoozedLength(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAudioPath(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setDaysOfWeek(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setHours(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setMinutes(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setRingDuration(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setSnoozeDuration(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *OrgKdeKclockAlarmInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeKclockAlarmInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26OrgKdeKclockAlarmInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeKclockAlarmInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeKclockAlarmInterface::audioPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OrgKdeKclockAlarmInterface::daysOfWeekChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OrgKdeKclockAlarmInterface::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void OrgKdeKclockAlarmInterface::hoursChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void OrgKdeKclockAlarmInterface::minutesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void OrgKdeKclockAlarmInterface::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void OrgKdeKclockAlarmInterface::nextRingTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void OrgKdeKclockAlarmInterface::rescheduleRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void OrgKdeKclockAlarmInterface::ringDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void OrgKdeKclockAlarmInterface::ringingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void OrgKdeKclockAlarmInterface::snoozeDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void OrgKdeKclockAlarmInterface::snoozedLengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
