/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<addlocationmodel.h>)
#  include <addlocationmodel.h>
#endif
#if __has_include(<alarm.h>)
#  include <alarm.h>
#endif
#if __has_include(<alarmmodel.h>)
#  include <alarmmodel.h>
#endif
#if __has_include(<kclockformat.h>)
#  include <kclockformat.h>
#endif
#if __has_include(<pipwindow.h>)
#  include <pipwindow.h>
#endif
#if __has_include(<savedlocationsmodel.h>)
#  include <savedlocationsmodel.h>
#endif
#if __has_include(<settingsmodel.h>)
#  include <settingsmodel.h>
#endif
#if __has_include(<stopwatchmodel.h>)
#  include <stopwatchmodel.h>
#endif
#if __has_include(<stopwatchtimer.h>)
#  include <stopwatchtimer.h>
#endif
#if __has_include(<timer.h>)
#  include <timer.h>
#endif
#if __has_include(<timermodel.h>)
#  include <timermodel.h>
#endif
#if __has_include(<timerpresetmodel.h>)
#  include <timerpresetmodel.h>
#endif
#if __has_include(<utilmodel.h>)
#  include <utilmodel.h>
#endif
#if __has_include(<windowexposure.h>)
#  include <windowexposure.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kclock()
{
    qmlRegisterModule("org.kde.kclock", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AddLocationSearchModel>("org.kde.kclock", 254);
    qmlRegisterTypesAndRevisions<Alarm>("org.kde.kclock", 254);
    qmlRegisterTypesAndRevisions<AlarmModel>("org.kde.kclock", 254);
    qmlRegisterEnum<AlarmModel::Status>("AlarmModel::Status");
    qmlRegisterTypesAndRevisions<KClockSettingsForeign>("org.kde.kclock", 254);
    qmlRegisterEnum<KClockSettings::EnumTimerNotification>("KClockSettings::EnumTimerNotification");
    qmlRegisterTypesAndRevisions<KclockFormat>("org.kde.kclock", 254);
    qmlRegisterTypesAndRevisions<PipWindow>("org.kde.kclock", 254);
    qmlRegisterAnonymousType<QQuickWindow, 254>("org.kde.kclock", 254);
    qmlRegisterAnonymousType<QWindow, 254>("org.kde.kclock", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<SavedLocationsModel>("org.kde.kclock", 254);
    qmlRegisterTypesAndRevisions<SettingsModel>("org.kde.kclock", 254);
    qmlRegisterTypesAndRevisions<StopwatchModel>("org.kde.kclock", 254);
    qmlRegisterTypesAndRevisions<StopwatchTimer>("org.kde.kclock", 254);
    qmlRegisterTypesAndRevisions<Timer>("org.kde.kclock", 254);
    qmlRegisterTypesAndRevisions<TimerModel>("org.kde.kclock", 254);
    qmlRegisterEnum<TimerModel::Status>("TimerModel::Status");
    qmlRegisterTypesAndRevisions<TimerPresetModel>("org.kde.kclock", 254);
    qmlRegisterTypesAndRevisions<UtilModel>("org.kde.kclock", 254);
    qmlRegisterTypesAndRevisions<WeekModel>("org.kde.kclock", 254);
    qmlRegisterTypesAndRevisions<WindowExposure>("org.kde.kclock", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kclock", 254, 254);
}

static const QQmlModuleRegistration orgkdekclockRegistration("org.kde.kclock", qml_register_types_org_kde_kclock);
