/****************************************************************************
** Meta object code from reading C++ file 'kclocksettingsadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kclocksettingsadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kclocksettingsadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21KClockSettingsAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KClockSettingsAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN21KClockSettingsAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KClockSettingsAdaptor",
        "D-Bus Interface",
        "local.KClockSettings",
        "D-Bus Introspection",
        "  <interface name=\"local.KClockSettings\">\n    <property access="
        "\"readwrite\" type=\"s\" name=\"timeFormat\"/>\n    <property acce"
        "ss=\"read\" type=\"b\" name=\"isTimeFormatImmutable\"/>\n    <prop"
        "erty access=\"read\" type=\"s\" name=\"defaultTimeFormatValue\"/>\n"
        "    <property access=\"readwrite\" type=\"i\" name=\"timerNotifica"
        "tion\"/>\n    <property access=\"read\" type=\"b\" name=\"isTimerN"
        "otificationImmutable\"/>\n    <property access=\"read\" type=\"i\""
        " name=\"defaultTimerNotificationValue\"/>\n    <signal name=\"time"
        "FormatChanged\"/>\n    <signal name=\"timerNotificationChanged\"/>"
        "\n  </interface>\n",
        "timeFormatChanged",
        "",
        "timerNotificationChanged",
        "defaultTimeFormatValue",
        "defaultTimerNotificationValue",
        "isTimeFormatImmutable",
        "isTimerNotificationImmutable",
        "timeFormat",
        "timerNotification"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'timeFormatChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timerNotificationChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'defaultTimeFormatValue'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'defaultTimerNotificationValue'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'isTimeFormatImmutable'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'isTimerNotificationImmutable'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'timeFormat'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'timerNotification'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KClockSettingsAdaptor, qt_meta_tag_ZN21KClockSettingsAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KClockSettingsAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KClockSettingsAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KClockSettingsAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21KClockSettingsAdaptorE_t>.metaTypes,
    nullptr
} };

void KClockSettingsAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KClockSettingsAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->timeFormatChanged(); break;
        case 1: _t->timerNotificationChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KClockSettingsAdaptor::*)()>(_a, &KClockSettingsAdaptor::timeFormatChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KClockSettingsAdaptor::*)()>(_a, &KClockSettingsAdaptor::timerNotificationChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->defaultTimeFormatValue(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->defaultTimerNotificationValue(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isTimeFormatImmutable(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isTimerNotificationImmutable(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->timeFormat(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->timerNotification(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setTimeFormat(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setTimerNotification(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KClockSettingsAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KClockSettingsAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KClockSettingsAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KClockSettingsAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KClockSettingsAdaptor::timeFormatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KClockSettingsAdaptor::timerNotificationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
