// This file is autogenerated. Changes will be overwritten.
#include "EJRQKI7XPS/moc_kclockdsettings.cpp"
#include "EWIEGA46WW/moc_abstractwakeupprovider.cpp"
#include "7HEHEGDA3T/moc_ScreenSaverUtils.cpp"
