/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.AlarmModel.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "alarmmodeladaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class AlarmModelAdaptor
 */

AlarmModelAdaptor::AlarmModelAdaptor(AlarmModel *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

AlarmModelAdaptor::~AlarmModelAdaptor()
{
    // destructor
}

void AlarmModelAdaptor::addAlarm(const QString &name, int hours, int minutes, int daysOfWeek, const QString &audioPath, int ringDuration, int snoozeDuration)
{
    // handle method call org.kde.kclock.AlarmModel.addAlarm
    parent()->addAlarm(name, hours, minutes, daysOfWeek, audioPath, ringDuration, snoozeDuration);
}

qulonglong AlarmModelAdaptor::getNextAlarm()
{
    // handle method call org.kde.kclock.AlarmModel.getNextAlarm
    return parent()->getNextAlarm();
}

void AlarmModelAdaptor::removeAlarm(const QString &uuid)
{
    // handle method call org.kde.kclock.AlarmModel.removeAlarm
    parent()->removeAlarm(uuid);
}


#include "moc_alarmmodeladaptor.cpp"
