/****************************************************************************
** Meta object code from reading C++ file 'alarmadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "alarmadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'alarmadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12AlarmAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto AlarmAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN12AlarmAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AlarmAdaptor",
        "D-Bus Interface",
        "org.kde.kclock.Alarm",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kclock.Alarm\">\n    <property access="
        "\"readwrite\" type=\"s\" name=\"name\"/>\n    <property access=\"r"
        "eadwrite\" type=\"b\" name=\"enabled\"/>\n    <property access=\"r"
        "eadwrite\" type=\"i\" name=\"hours\"/>\n    <property access=\"rea"
        "dwrite\" type=\"i\" name=\"minutes\"/>\n    <property access=\"rea"
        "dwrite\" type=\"i\" name=\"daysOfWeek\"/>\n    <property access=\""
        "readwrite\" type=\"s\" name=\"audioPath\"/>\n    <property access="
        "\"readwrite\" type=\"i\" name=\"ringDuration\"/>\n    <property ac"
        "cess=\"readwrite\" type=\"i\" name=\"snoozeDuration\"/>\n    <prop"
        "erty access=\"read\" type=\"i\" name=\"snoozedLength\"/>\n    <pro"
        "perty access=\"read\" type=\"b\" name=\"ringing\"/>\n    <property"
        " access=\"read\" type=\"t\" name=\"nextRingTime\"/>\n    <signal n"
        "ame=\"nameChanged\"/>\n    <signal name=\"enabledChanged\"/>\n    "
        "<signal name=\"hoursChanged\"/>\n    <signal name=\"minutesChanged"
        "\"/>\n    <signal name=\"daysOfWeekChanged\"/>\n    <signal name=\""
        "audioPathChanged\"/>\n    <signal name=\"ringDurationChanged\"/>\n"
        "    <signal name=\"snoozeDurationChanged\"/>\n    <signal name=\"s"
        "noozedLengthChanged\"/>\n    <signal name=\"ringingChanged\"/>\n  "
        "  <signal name=\"nextRingTimeChanged\"/>\n    <signal name=\"resch"
        "eduleRequested\"/>\n    <method name=\"dismiss\"/>\n    <method na"
        "me=\"snooze\"/>\n    <method name=\"save\"/>\n    <method name=\"u"
        "uid\">\n      <arg direction=\"out\" type=\"s\"/>\n    </method>\n"
        "  </interface>\n",
        "audioPathChanged",
        "",
        "daysOfWeekChanged",
        "enabledChanged",
        "hoursChanged",
        "minutesChanged",
        "nameChanged",
        "nextRingTimeChanged",
        "rescheduleRequested",
        "ringDurationChanged",
        "ringingChanged",
        "snoozeDurationChanged",
        "snoozedLengthChanged",
        "dismiss",
        "save",
        "snooze",
        "uuid",
        "audioPath",
        "daysOfWeek",
        "enabled",
        "hours",
        "minutes",
        "name",
        "nextRingTime",
        "ringDuration",
        "ringing",
        "snoozeDuration",
        "snoozedLength"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'audioPathChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'daysOfWeekChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoursChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minutesChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextRingTimeChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rescheduleRequested'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ringDurationChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ringingChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'snoozeDurationChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'snoozedLengthChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'dismiss'
        QtMocHelpers::SlotData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'snooze'
        QtMocHelpers::SlotData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'uuid'
        QtMocHelpers::SlotData<QString()>(21, 6, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'audioPath'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'daysOfWeek'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hours'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'minutes'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'nextRingTime'
        QtMocHelpers::PropertyData<qulonglong>(28, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'ringDuration'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'ringing'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'snoozeDuration'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'snoozedLength'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<AlarmAdaptor, qt_meta_tag_ZN12AlarmAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AlarmAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AlarmAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AlarmAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12AlarmAdaptorE_t>.metaTypes,
    nullptr
} };

void AlarmAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AlarmAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->audioPathChanged(); break;
        case 1: _t->daysOfWeekChanged(); break;
        case 2: _t->enabledChanged(); break;
        case 3: _t->hoursChanged(); break;
        case 4: _t->minutesChanged(); break;
        case 5: _t->nameChanged(); break;
        case 6: _t->nextRingTimeChanged(); break;
        case 7: _t->rescheduleRequested(); break;
        case 8: _t->ringDurationChanged(); break;
        case 9: _t->ringingChanged(); break;
        case 10: _t->snoozeDurationChanged(); break;
        case 11: _t->snoozedLengthChanged(); break;
        case 12: _t->dismiss(); break;
        case 13: _t->save(); break;
        case 14: _t->snooze(); break;
        case 15: { QString _r = _t->uuid();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AlarmAdaptor::*)()>(_a, &AlarmAdaptor::audioPathChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlarmAdaptor::*)()>(_a, &AlarmAdaptor::daysOfWeekChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlarmAdaptor::*)()>(_a, &AlarmAdaptor::enabledChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlarmAdaptor::*)()>(_a, &AlarmAdaptor::hoursChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlarmAdaptor::*)()>(_a, &AlarmAdaptor::minutesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlarmAdaptor::*)()>(_a, &AlarmAdaptor::nameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlarmAdaptor::*)()>(_a, &AlarmAdaptor::nextRingTimeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlarmAdaptor::*)()>(_a, &AlarmAdaptor::rescheduleRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlarmAdaptor::*)()>(_a, &AlarmAdaptor::ringDurationChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlarmAdaptor::*)()>(_a, &AlarmAdaptor::ringingChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlarmAdaptor::*)()>(_a, &AlarmAdaptor::snoozeDurationChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlarmAdaptor::*)()>(_a, &AlarmAdaptor::snoozedLengthChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->audioPath(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->daysOfWeek(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->hours(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->minutes(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 6: *reinterpret_cast<qulonglong*>(_v) = _t->nextRingTime(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->ringDuration(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->ringing(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->snoozeDuration(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->snoozedLength(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAudioPath(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setDaysOfWeek(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setHours(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setMinutes(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setRingDuration(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setSnoozeDuration(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AlarmAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AlarmAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AlarmAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int AlarmAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void AlarmAdaptor::audioPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AlarmAdaptor::daysOfWeekChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AlarmAdaptor::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AlarmAdaptor::hoursChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AlarmAdaptor::minutesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AlarmAdaptor::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AlarmAdaptor::nextRingTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AlarmAdaptor::rescheduleRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AlarmAdaptor::ringDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void AlarmAdaptor::ringingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void AlarmAdaptor::snoozeDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void AlarmAdaptor::snoozedLengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
