/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.TimerModel.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef TIMERMODELADAPTOR_H
#define TIMERMODELADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "timermodel.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kclock.TimerModel
 */
class TimerModelAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kclock.TimerModel")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kclock.TimerModel\">\n"
"    <property access=\"readwrite\" type=\"s\" name=\"defaultAudioLocation\"/>\n"
"    <signal name=\"timerAdded\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </signal>\n"
"    <signal name=\"timerRemoved\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </signal>\n"
"    <signal name=\"defaultAudioLocationChanged\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </signal>\n"
"    <method name=\"timers\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"addTimer\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"length\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"label\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"looping\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"commandTimeout\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"running\"/>\n"
"    </method>\n"
"    <method name=\"removeTimer\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"uuid\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    TimerModelAdaptor(TimerModel *parent);
    ~TimerModelAdaptor() override;

    inline TimerModel *parent() const
    { return static_cast<TimerModel *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QString defaultAudioLocation READ defaultAudioLocation WRITE setDefaultAudioLocation)
    QString defaultAudioLocation() const;
    void setDefaultAudioLocation(const QString &value);

public Q_SLOTS: // METHODS
    void addTimer(int length, const QString &label, bool looping, const QString &commandTimeout, bool running);
    void removeTimer(const QString &uuid);
    QStringList timers();
Q_SIGNALS: // SIGNALS
    void defaultAudioLocationChanged(const QString &in0);
    void timerAdded(const QString &in0);
    void timerRemoved(const QString &in0);
};

#endif
