/****************************************************************************
** Meta object code from reading C++ file 'utilmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kclock-26.04.2/src/kclock/utilmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'utilmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9UtilModelE_t {};
} // unnamed namespace

template <> constexpr inline auto UtilModel::qt_create_metaobjectdata<qt_meta_tag_ZN9UtilModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UtilModel",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "use24HourTimeChanged",
        "",
        "systemHasPlasmaMobileSoundTheme",
        "systemHasOceanSoundTheme",
        "getDefaultAlarmFileLocation",
        "msToHoursPart",
        "ms",
        "msToMinutesPart",
        "msToSecondsPart",
        "msToSmallPart",
        "displayTwoDigits",
        "amount",
        "repeatFormat",
        "dayOfWeek",
        "applyPlasmaImageSet",
        "KSvg::Svg*",
        "svg",
        "tzName",
        "use24HourTime"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'use24HourTimeChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'systemHasPlasmaMobileSoundTheme'
        QtMocHelpers::MethodData<bool()>(7, 6, QMC::AccessPublic, QMetaType::Bool),
        // Method 'systemHasOceanSoundTheme'
        QtMocHelpers::MethodData<bool()>(8, 6, QMC::AccessPublic, QMetaType::Bool),
        // Method 'getDefaultAlarmFileLocation'
        QtMocHelpers::MethodData<QString()>(9, 6, QMC::AccessPublic, QMetaType::QString),
        // Method 'msToHoursPart'
        QtMocHelpers::MethodData<qint64(qint64) const>(10, 6, QMC::AccessPublic, QMetaType::LongLong, {{
            { QMetaType::LongLong, 11 },
        }}),
        // Method 'msToMinutesPart'
        QtMocHelpers::MethodData<qint64(qint64) const>(12, 6, QMC::AccessPublic, QMetaType::LongLong, {{
            { QMetaType::LongLong, 11 },
        }}),
        // Method 'msToSecondsPart'
        QtMocHelpers::MethodData<qint64(qint64) const>(13, 6, QMC::AccessPublic, QMetaType::LongLong, {{
            { QMetaType::LongLong, 11 },
        }}),
        // Method 'msToSmallPart'
        QtMocHelpers::MethodData<qint64(qint64) const>(14, 6, QMC::AccessPublic, QMetaType::LongLong, {{
            { QMetaType::LongLong, 11 },
        }}),
        // Method 'displayTwoDigits'
        QtMocHelpers::MethodData<QString(const qint64 &)>(15, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::LongLong, 16 },
        }}),
        // Method 'repeatFormat'
        QtMocHelpers::MethodData<QString(int) const>(17, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'applyPlasmaImageSet'
        QtMocHelpers::MethodData<void(KSvg::Svg *)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'tzName'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'use24HourTime'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<UtilModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject UtilModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UtilModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UtilModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9UtilModelE_t>.metaTypes,
    nullptr
} };

void UtilModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UtilModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->use24HourTimeChanged(); break;
        case 1: { bool _r = _t->systemHasPlasmaMobileSoundTheme();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->systemHasOceanSoundTheme();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->getDefaultAlarmFileLocation();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { qint64 _r = _t->msToHoursPart((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 5: { qint64 _r = _t->msToMinutesPart((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 6: { qint64 _r = _t->msToSecondsPart((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 7: { qint64 _r = _t->msToSmallPart((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->displayTwoDigits((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->repeatFormat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->applyPlasmaImageSet((*reinterpret_cast<std::add_pointer_t<KSvg::Svg*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UtilModel::*)()>(_a, &UtilModel::use24HourTimeChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->getCurrentTimeZoneName(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->use24HourTime(); break;
        default: break;
        }
    }
}

const QMetaObject *UtilModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UtilModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UtilModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UtilModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void UtilModel::use24HourTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
