/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.TimerModel.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef TIMERMODELINTERFACE_H
#define TIMERMODELINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.kclock.TimerModel
 */
class OrgKdeKclockTimerModelInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.kclock.TimerModel"; }

public:
    OrgKdeKclockTimerModelInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKclockTimerModelInterface();

    Q_PROPERTY(QString defaultAudioLocation READ defaultAudioLocation WRITE setDefaultAudioLocation)
    inline QString defaultAudioLocation() const
    { return qvariant_cast< QString >(property("defaultAudioLocation")); }
    inline void setDefaultAudioLocation(const QString &value)
    { setProperty("defaultAudioLocation", QVariant::fromValue(value)); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> addTimer(int length, const QString &label, bool looping, const QString &commandTimeout, bool running)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(length) << QVariant::fromValue(label) << QVariant::fromValue(looping) << QVariant::fromValue(commandTimeout) << QVariant::fromValue(running);
        return asyncCallWithArgumentList(QStringLiteral("addTimer"), argumentList);
    }

    inline QDBusPendingReply<> removeTimer(const QString &uuid)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(uuid);
        return asyncCallWithArgumentList(QStringLiteral("removeTimer"), argumentList);
    }

    inline QDBusPendingReply<QStringList> timers()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("timers"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void defaultAudioLocationChanged(const QString &in0);
    void timerAdded(const QString &in0);
    void timerRemoved(const QString &in0);
};

namespace org {
  namespace kde {
    namespace kclock {
      using TimerModel = ::OrgKdeKclockTimerModelInterface;
    }
  }
}

#endif
