/****************************************************************************
** Meta object code from reading C++ file 'alarm.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kclock-26.04.2/src/kclock/alarm.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'alarm.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5AlarmE_t {};
} // unnamed namespace

template <> constexpr inline auto Alarm::qt_create_metaobjectdata<qt_meta_tag_ZN5AlarmE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Alarm",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Managed by AlarmModel",
        "nameChanged",
        "",
        "enabledChanged",
        "formattedTimeChanged",
        "hoursChanged",
        "minutesChanged",
        "daysOfWeekChanged",
        "audioPathChanged",
        "ringDurationChanged",
        "snoozeDurationChanged",
        "snoozedLengthChanged",
        "ringingChanged",
        "nextRingTimeChanged",
        "updateName",
        "updateEnabled",
        "updateHours",
        "updateMinutes",
        "updateDaysOfWeek",
        "updateAudioPath",
        "updateRingDuration",
        "updateSnoozeDuration",
        "updateSnoozedLength",
        "updateRinging",
        "updateNextRingTime",
        "dismiss",
        "snooze",
        "timeToRingFormatted",
        "save",
        "name",
        "enabled",
        "formattedTime",
        "hours",
        "minutes",
        "daysOfWeek",
        "audioPath",
        "ringDuration",
        "snoozeDuration",
        "snoozedLength",
        "ringing",
        "nextRingTime"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'formattedTimeChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoursChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minutesChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'daysOfWeekChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioPathChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ringDurationChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'snoozeDurationChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'snoozedLengthChanged'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ringingChanged'
        QtMocHelpers::SignalData<void()>(18, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextRingTimeChanged'
        QtMocHelpers::SignalData<void()>(19, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateName'
        QtMocHelpers::SlotData<void()>(20, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateEnabled'
        QtMocHelpers::SlotData<void()>(21, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateHours'
        QtMocHelpers::SlotData<void()>(22, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMinutes'
        QtMocHelpers::SlotData<void()>(23, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateDaysOfWeek'
        QtMocHelpers::SlotData<void()>(24, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateAudioPath'
        QtMocHelpers::SlotData<void()>(25, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateRingDuration'
        QtMocHelpers::SlotData<void()>(26, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSnoozeDuration'
        QtMocHelpers::SlotData<void()>(27, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSnoozedLength'
        QtMocHelpers::SlotData<void()>(28, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateRinging'
        QtMocHelpers::SlotData<void()>(29, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateNextRingTime'
        QtMocHelpers::SlotData<void()>(30, 8, QMC::AccessPrivate, QMetaType::Void),
        // Method 'dismiss'
        QtMocHelpers::MethodData<void()>(31, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'snooze'
        QtMocHelpers::MethodData<void()>(32, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'timeToRingFormatted'
        QtMocHelpers::MethodData<QString()>(33, 8, QMC::AccessPublic, QMetaType::QString),
        // Method 'save'
        QtMocHelpers::MethodData<void()>(34, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'formattedTime'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'hours'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'minutes'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'daysOfWeek'
        QtMocHelpers::PropertyData<int>(40, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'audioPath'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'ringDuration'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'snoozeDuration'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'snoozedLength'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags, 9),
        // property 'ringing'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'nextRingTime'
        QtMocHelpers::PropertyData<quint64>(46, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Alarm, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Alarm::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5AlarmE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5AlarmE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5AlarmE_t>.metaTypes,
    nullptr
} };

void Alarm::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Alarm *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->enabledChanged(); break;
        case 2: _t->formattedTimeChanged(); break;
        case 3: _t->hoursChanged(); break;
        case 4: _t->minutesChanged(); break;
        case 5: _t->daysOfWeekChanged(); break;
        case 6: _t->audioPathChanged(); break;
        case 7: _t->ringDurationChanged(); break;
        case 8: _t->snoozeDurationChanged(); break;
        case 9: _t->snoozedLengthChanged(); break;
        case 10: _t->ringingChanged(); break;
        case 11: _t->nextRingTimeChanged(); break;
        case 12: _t->updateName(); break;
        case 13: _t->updateEnabled(); break;
        case 14: _t->updateHours(); break;
        case 15: _t->updateMinutes(); break;
        case 16: _t->updateDaysOfWeek(); break;
        case 17: _t->updateAudioPath(); break;
        case 18: _t->updateRingDuration(); break;
        case 19: _t->updateSnoozeDuration(); break;
        case 20: _t->updateSnoozedLength(); break;
        case 21: _t->updateRinging(); break;
        case 22: _t->updateNextRingTime(); break;
        case 23: _t->dismiss(); break;
        case 24: _t->snooze(); break;
        case 25: { QString _r = _t->timeToRingFormatted();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->save(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Alarm::*)()>(_a, &Alarm::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Alarm::*)()>(_a, &Alarm::enabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Alarm::*)()>(_a, &Alarm::formattedTimeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Alarm::*)()>(_a, &Alarm::hoursChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Alarm::*)()>(_a, &Alarm::minutesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Alarm::*)()>(_a, &Alarm::daysOfWeekChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Alarm::*)()>(_a, &Alarm::audioPathChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Alarm::*)()>(_a, &Alarm::ringDurationChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Alarm::*)()>(_a, &Alarm::snoozeDurationChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Alarm::*)()>(_a, &Alarm::snoozedLengthChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Alarm::*)()>(_a, &Alarm::ringingChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Alarm::*)()>(_a, &Alarm::nextRingTimeChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->formattedTime(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->hours(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->minutes(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->daysOfWeek(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->audioPath(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->ringDuration(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->snoozeDuration(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->snoozedLength(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->ringing(); break;
        case 11: *reinterpret_cast<quint64*>(_v) = _t->nextRingTime(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setHours(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setMinutes(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setDaysOfWeek(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setAudioPath(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setRingDuration(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setSnoozeDuration(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Alarm::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Alarm::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5AlarmE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Alarm::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 27;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Alarm::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Alarm::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Alarm::formattedTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Alarm::hoursChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Alarm::minutesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Alarm::daysOfWeekChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Alarm::audioPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Alarm::ringDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Alarm::snoozeDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Alarm::snoozedLengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Alarm::ringingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Alarm::nextRingTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
