// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_TIMERMODEL_DEBUG_DEBUG_TIMERMODEL_H
#define ECM_QLOGGINGCATEGORY_TIMERMODEL_DEBUG_DEBUG_TIMERMODEL_H

#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(TIMERMODEL_DEBUG)


#endif
