/****************************************************************************
** Meta object code from reading C++ file 'alarmmodeladaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "alarmmodeladaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'alarmmodeladaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17AlarmModelAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto AlarmModelAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN17AlarmModelAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AlarmModelAdaptor",
        "D-Bus Interface",
        "org.kde.kclock.AlarmModel",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kclock.AlarmModel\">\n    <signal name"
        "=\"alarmAdded\">\n      <arg direction=\"out\" type=\"s\" name=\"u"
        "uid\"/>\n    </signal>\n    <signal name=\"alarmRemoved\">\n      "
        "<arg direction=\"out\" type=\"s\" name=\"uuid\"/>\n    </signal>\n"
        "    <signal name=\"nextAlarm\">\n      <arg direction=\"out\" type"
        "=\"t\" name=\"nextAlarmTimeStamp\"/>\n    </signal>\n    <method n"
        "ame=\"getNextAlarm\">\n      <arg direction=\"out\" type=\"t\"/>\n"
        "    </method>\n    <method name=\"removeAlarm\">\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"uuid\"/>\n    </method>\n    <method"
        " name=\"addAlarm\">\n      <arg direction=\"in\" type=\"s\" name=\""
        "name\"/>\n      <arg direction=\"in\" type=\"i\" name=\"hours\"/>\n"
        "      <arg direction=\"in\" type=\"i\" name=\"minutes\"/>\n      <"
        "arg direction=\"in\" type=\"i\" name=\"daysOfWeek\"/>\n      <arg "
        "direction=\"in\" type=\"s\" name=\"audioPath\"/>\n      <arg direc"
        "tion=\"in\" type=\"i\" name=\"ringDuration\"/>\n      <arg directi"
        "on=\"in\" type=\"i\" name=\"snoozeDuration\"/>\n    </method>\n  <"
        "/interface>\n",
        "alarmAdded",
        "",
        "uuid",
        "alarmRemoved",
        "nextAlarm",
        "nextAlarmTimeStamp",
        "addAlarm",
        "name",
        "hours",
        "minutes",
        "daysOfWeek",
        "audioPath",
        "ringDuration",
        "snoozeDuration",
        "getNextAlarm",
        "removeAlarm"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'alarmAdded'
        QtMocHelpers::SignalData<void(const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'alarmRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'nextAlarm'
        QtMocHelpers::SignalData<void(qulonglong)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 10 },
        }}),
        // Slot 'addAlarm'
        QtMocHelpers::SlotData<void(const QString &, int, int, int, const QString &, int, int)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::Int, 13 }, { QMetaType::Int, 14 }, { QMetaType::Int, 15 },
            { QMetaType::QString, 16 }, { QMetaType::Int, 17 }, { QMetaType::Int, 18 },
        }}),
        // Slot 'getNextAlarm'
        QtMocHelpers::SlotData<qulonglong()>(19, 6, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'removeAlarm'
        QtMocHelpers::SlotData<void(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<AlarmModelAdaptor, qt_meta_tag_ZN17AlarmModelAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AlarmModelAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AlarmModelAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AlarmModelAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17AlarmModelAdaptorE_t>.metaTypes,
    nullptr
} };

void AlarmModelAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AlarmModelAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->alarmAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->alarmRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->nextAlarm((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 3: _t->addAlarm((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 4: { qulonglong _r = _t->getNextAlarm();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->removeAlarm((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AlarmModelAdaptor::*)(const QString & )>(_a, &AlarmModelAdaptor::alarmAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlarmModelAdaptor::*)(const QString & )>(_a, &AlarmModelAdaptor::alarmRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AlarmModelAdaptor::*)(qulonglong )>(_a, &AlarmModelAdaptor::nextAlarm, 2))
            return;
    }
}

const QMetaObject *AlarmModelAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AlarmModelAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AlarmModelAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int AlarmModelAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void AlarmModelAdaptor::alarmAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AlarmModelAdaptor::alarmRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AlarmModelAdaptor::nextAlarm(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
