/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.Timer.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef TIMERADAPTOR_H
#define TIMERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "timer.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kclock.Timer
 */
class TimerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kclock.Timer")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kclock.Timer\">\n"
"    <property access=\"readwrite\" type=\"i\" name=\"length\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"timeCompleted\"/>\n"
"    <property access=\"readwrite\" type=\"s\" name=\"label\"/>\n"
"    <property access=\"readwrite\" type=\"s\" name=\"commandTimeout\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"running\"/>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"looping\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"ringing\"/>\n"
"    <signal name=\"timeCompletedChanged\"/>\n"
"    <signal name=\"lengthChanged\"/>\n"
"    <signal name=\"labelChanged\"/>\n"
"    <signal name=\"commandTimeoutChanged\"/>\n"
"    <signal name=\"runningChanged\"/>\n"
"    <signal name=\"loopingChanged\"/>\n"
"    <signal name=\"ringingChanged\"/>\n"
"    <method name=\"toggleRunning\"/>\n"
"    <method name=\"toggleLooping\"/>\n"
"    <method name=\"reset\"/>\n"
"    <method name=\"elapsed\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"uuid\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"timeCompleted\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"dismiss\"/>\n"
"  </interface>\n"
        "")
public:
    TimerAdaptor(Timer *parent);
    ~TimerAdaptor() override;

    inline Timer *parent() const
    { return static_cast<Timer *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QString commandTimeout READ commandTimeout WRITE setCommandTimeout)
    QString commandTimeout() const;
    void setCommandTimeout(const QString &value);

    Q_PROPERTY(QString label READ label WRITE setLabel)
    QString label() const;
    void setLabel(const QString &value);

    Q_PROPERTY(int length READ length WRITE setLength)
    int length() const;
    void setLength(int value);

    Q_PROPERTY(bool looping READ looping WRITE setLooping)
    bool looping() const;
    void setLooping(bool value);

    Q_PROPERTY(bool ringing READ ringing)
    bool ringing() const;

    Q_PROPERTY(bool running READ running)
    bool running() const;

    Q_PROPERTY(int timeCompleted READ timeCompleted)
    int timeCompleted() const;

public Q_SLOTS: // METHODS
    void dismiss();
    int elapsed();
    void reset();
    int timeCompleted();
    void toggleLooping();
    void toggleRunning();
    QString uuid();
Q_SIGNALS: // SIGNALS
    void commandTimeoutChanged();
    void labelChanged();
    void lengthChanged();
    void loopingChanged();
    void ringingChanged();
    void runningChanged();
    void timeCompletedChanged();
};

#endif
