/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.AlarmModel.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef ALARMMODELADAPTOR_H
#define ALARMMODELADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "alarmmodel.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kclock.AlarmModel
 */
class AlarmModelAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kclock.AlarmModel")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kclock.AlarmModel\">\n"
"    <signal name=\"alarmAdded\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"uuid\"/>\n"
"    </signal>\n"
"    <signal name=\"alarmRemoved\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"uuid\"/>\n"
"    </signal>\n"
"    <signal name=\"nextAlarm\">\n"
"      <arg direction=\"out\" type=\"t\" name=\"nextAlarmTimeStamp\"/>\n"
"    </signal>\n"
"    <method name=\"getNextAlarm\">\n"
"      <arg direction=\"out\" type=\"t\"/>\n"
"    </method>\n"
"    <method name=\"removeAlarm\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"uuid\"/>\n"
"    </method>\n"
"    <method name=\"addAlarm\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"hours\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"minutes\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"daysOfWeek\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"audioPath\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"ringDuration\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"snoozeDuration\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    AlarmModelAdaptor(AlarmModel *parent);
    ~AlarmModelAdaptor() override;

    inline AlarmModel *parent() const
    { return static_cast<AlarmModel *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void addAlarm(const QString &name, int hours, int minutes, int daysOfWeek, const QString &audioPath, int ringDuration, int snoozeDuration);
    qulonglong getNextAlarm();
    void removeAlarm(const QString &uuid);
Q_SIGNALS: // SIGNALS
    void alarmAdded(const QString &uuid);
    void alarmRemoved(const QString &uuid);
    void nextAlarm(qulonglong nextAlarmTimeStamp);
};

#endif
