/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xec,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xe2,0x6,0x15,0xf,0x0,0x16,0xd2,0x35,0x1d,0x50,0x6f,0x73,
  0x83,0x5b,0x22,0x71,0xa7,0xd0,0xb6,0x7c,0xa3,0xb4,0x4f,0x1c,0x8c,0x53,0xc4,0x89,
  0xf4,0x68,0x73,0xf3,0x6b,0x75,0x67,0x62,0x67,0x6a,0x30,0x0,0x2c,0x0,0x2c,0x0,
  0xbc,0x5c,0x81,0x69,0x0,0x8e,0x60,0x10,0x68,0x56,0xd7,0x82,0x51,0x4a,0x35,0xbe,
  0x52,0x4d,0x51,0x84,0x86,0x53,0x92,0xc,0x99,0xe8,0x1e,0xc5,0x69,0x2e,0x59,0x4d,
  0x78,0x69,0x46,0x62,0x77,0x4c,0x72,0x32,0x92,0x9c,0xc6,0x6f,0xd2,0x4d,0xd1,0x5f,
  0x8e,0xf7,0xee,0x3f,0x3d,0x3d,0xa2,0x62,0x6f,0xee,0xe1,0x3b,0xe3,0x94,0x98,0x42,
  0xd1,0x4e,0x6f,0x6c,0x26,0xb3,0x8,0x27,0x78,0xa8,0xad,0xb6,0x55,0x46,0xaf,0x96,
  0x2e,0xf,0x1d,0x55,0x91,0x6d,0x41,0x6a,0x3d,0x3e,0xe2,0x5,0xb0,0x91,0x4f,0x1d,
  0x19,0x29,0xa7,0x8b,0x76,0x25,0xa0,0x42,0xe9,0xda,0x6a,0xdc,0x6b,0xb3,0x42,0x5b,
  0xed,0x75,0xb7,0xef,0x9e,0x1e,0x5e,0xf,0x67,0xff,0x8,0xcb,0x9f,0x47,0xde,0xd,
  0xed,0x6e,0xe9,0x81,0x57,0xc4,0xfd,0x1,0xcc,0x72,0x42,0xb8,0x18,0xa2,0xa2,0x2a,
  0xf6,0xda,0x8b,0x5d,0x11,0x45,0x6a,0xc2,0x7a,0x55,0xe0,0x5b,0xc5,0xd8,0x56,0xbb,
  0xd3,0xc0,0x8a,0xf3,0x69,0x2f,0x9e,0xe,0x9d,0x31,0x19,0xaa,0xa4,0x3e,0x9a,0xd3,
  0x15,0x56,0x3,0x80,0x85,0xa8,0x91,0x96,0x8,0xc9,0x8c,0x34,0x69,0xb6,0x3,0x30,
  0x44,0x88,0x54,0xda,0x1c,0x31,0x1c,0x3,0x11,0x83,0x1c,0x31,0x46,0x99,0x99,0x60,
  0x46,0x36,0x69,0xe1,0x95,0xe,0x73,0xbb,0x34,0xa1,0x5c,0xb6,0xc,0xa3,0x95,0xd5,
  0x47,0x24,0xa9,0x12,0x22,0xeb,0x8e,0x3e,0xad,0x60,0xea,0xca,0x2d,0x68,0x8c,0x2b,
  0x4a,0x77,0x66,0x1f,0x93,0x4e,0x94,0x76,0xfa,0x83,0x8c,0x51,0xc9,0xc2,0xee,0x59,
  0x7f,0x5,0xfd,0x2,0xe7,0x36,0x49,0x3d,0xd4,0x8b,0xa1,0xda,0x75,0xb6,0x23,0x7d,
  0x7b,0xd5,0xfc,0x3c,0x88,0xb9,0x61,0x49,0x93,0x6d,0x90,0xb2,0x86,0xcf,0x4f,0x4b,
  0x71,0x43,0x93,0x9c,0x7b,0x2a,0x98,0xcd,0x57,0xa8,0x7b,0xe,0x89,0xa6,0x27,0xa5,
  0x2b,0xa9,0x1f,0x4e,0x46,0x90,0x6b,0x2c,0x30,0xdb,0xae,0x48,0xc3,0x2c,0x73,0x85,
  0xbc,0x8c,0x9e,0x85,0x9,0x83,0xe5,0x21,0x82,0x3c,0xa1,0xd,0x8d,0x81,0x2b,0xbd,
  0xa0,0x2,0x8d,0xfa,0x7c,0x49,0x49,0x64,0x19,0xf0,0xa4,0xb1,0x12,0xb3,0x5,0x52,
  0xc8,0x26,0x14,0x49,0x70,0x8c,0x36,0x3d,0x37,0xd5,0xd0,0x2d,0x43,0x50,0xa0,0x9,
  0x3a,0xfb,0xf1,0xd1,0x3b,0x43,0xd0,0xe7,0x60,0xce,0x3c,0xc,0x1b,0x57,0xaa,0x87,
  0xa2,0x40,0xce,0x9a,0xf5,0xa8,0x95,0xde,0xfc,0xb1,0x55,0xc0,0x47,0x3b,0xde,0x7c,
  0xf,0xae,0x73,0x7c,0x27,0xb2,0xef,0xa9,0x98,0x5e,0xea,0xe,0x5d,0xb7,0xcf,0x9,
  0xae,0x7c,0xc8,0xa2,0x0,0xdd,0xfb,0xb5,0x1c,0x80,0x7,0xd0,0x22,0x41,0xb4,0xbf,
  0xce,0x77,0x81,0x1d,0xb,0x65,0x63,0xe8,0xd1,0x4a,0x15,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // kclock
  0x0,0x6,
  0x7,0x1a,0x35,0x9b,
  0x0,0x6b,
  0x0,0x63,0x0,0x6c,0x0,0x6f,0x0,0x63,0x0,0x6b,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9e,0x92,0x2b,0x78,0x98,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9e,0x92,0x2b,0x78,0x98,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9e,0x92,0x2b,0x78,0x98,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9e,0x92,0x2b,0x78,0x98,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9e,0x92,0x2b,0x78,0x98,
  // :/qt/qml/org/kde/kclock
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9e,0x92,0x2b,0x78,0x98,
  // :/qt/qml/org/kde/kclock/qmldir
  0x0,0x0,0x0,0x40,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9e,0x92,0x2b,0x78,0x98,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_kclock)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_kclock)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_kclock)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_kclock)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_kclock)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_kclock)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
