/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.KClockSettings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KCLOCKSETTINGSADAPTOR_H
#define KCLOCKSETTINGSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "kclockdsettings.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface local.KClockSettings
 */
class KClockSettingsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "local.KClockSettings")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"local.KClockSettings\">\n"
"    <property access=\"readwrite\" type=\"s\" name=\"timeFormat\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"isTimeFormatImmutable\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"defaultTimeFormatValue\"/>\n"
"    <property access=\"readwrite\" type=\"i\" name=\"timerNotification\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"isTimerNotificationImmutable\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"defaultTimerNotificationValue\"/>\n"
"    <signal name=\"timeFormatChanged\"/>\n"
"    <signal name=\"timerNotificationChanged\"/>\n"
"  </interface>\n"
        "")
public:
    KClockSettingsAdaptor(KClockSettings *parent);
    ~KClockSettingsAdaptor() override;

    inline KClockSettings *parent() const
    { return static_cast<KClockSettings *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QString defaultTimeFormatValue READ defaultTimeFormatValue)
    QString defaultTimeFormatValue() const;

    Q_PROPERTY(int defaultTimerNotificationValue READ defaultTimerNotificationValue)
    int defaultTimerNotificationValue() const;

    Q_PROPERTY(bool isTimeFormatImmutable READ isTimeFormatImmutable)
    bool isTimeFormatImmutable() const;

    Q_PROPERTY(bool isTimerNotificationImmutable READ isTimerNotificationImmutable)
    bool isTimerNotificationImmutable() const;

    Q_PROPERTY(QString timeFormat READ timeFormat WRITE setTimeFormat)
    QString timeFormat() const;
    void setTimeFormat(const QString &value);

    Q_PROPERTY(int timerNotification READ timerNotification WRITE setTimerNotification)
    int timerNotification() const;
    void setTimerNotification(int value);

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void timeFormatChanged();
    void timerNotificationChanged();
};

#endif
