/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.KClockSettings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KCLOCKSETTINGSINTERFACE_H
#define KCLOCKSETTINGSINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface local.KClockSettings
 */
class LocalKClockSettingsInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "local.KClockSettings"; }

public:
    LocalKClockSettingsInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~LocalKClockSettingsInterface();

    Q_PROPERTY(QString defaultTimeFormatValue READ defaultTimeFormatValue)
    inline QString defaultTimeFormatValue() const
    { return qvariant_cast< QString >(property("defaultTimeFormatValue")); }

    Q_PROPERTY(int defaultTimerNotificationValue READ defaultTimerNotificationValue)
    inline int defaultTimerNotificationValue() const
    { return qvariant_cast< int >(property("defaultTimerNotificationValue")); }

    Q_PROPERTY(bool isTimeFormatImmutable READ isTimeFormatImmutable)
    inline bool isTimeFormatImmutable() const
    { return qvariant_cast< bool >(property("isTimeFormatImmutable")); }

    Q_PROPERTY(bool isTimerNotificationImmutable READ isTimerNotificationImmutable)
    inline bool isTimerNotificationImmutable() const
    { return qvariant_cast< bool >(property("isTimerNotificationImmutable")); }

    Q_PROPERTY(QString timeFormat READ timeFormat WRITE setTimeFormat)
    inline QString timeFormat() const
    { return qvariant_cast< QString >(property("timeFormat")); }
    inline void setTimeFormat(const QString &value)
    { setProperty("timeFormat", QVariant::fromValue(value)); }

    Q_PROPERTY(int timerNotification READ timerNotification WRITE setTimerNotification)
    inline int timerNotification() const
    { return qvariant_cast< int >(property("timerNotification")); }
    inline void setTimerNotification(int value)
    { setProperty("timerNotification", QVariant::fromValue(value)); }

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void timeFormatChanged();
    void timerNotificationChanged();
};

namespace local {
  using KClockSettings = ::LocalKClockSettingsInterface;
}

#endif
