/****************************************************************************
** Meta object code from reading C++ file 'timer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kclock-26.04.2/src/kclockd/timer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'timer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5TimerE_t {};
} // unnamed namespace

template <> constexpr inline auto Timer::qt_create_metaobjectdata<qt_meta_tag_ZN5TimerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Timer",
        "D-Bus Interface",
        "org.kde.kclock.Timer",
        "timeCompletedChanged",
        "",
        "lengthChanged",
        "labelChanged",
        "commandTimeoutChanged",
        "runningChanged",
        "loopingChanged",
        "ringingChanged",
        "timeUp",
        "cookie",
        "reschedule",
        "toggleRunning",
        "toggleLooping",
        "reset",
        "elapsed",
        "uuid",
        "timeCompleted",
        "dismiss",
        "length",
        "label",
        "commandTimeout",
        "running",
        "looping",
        "ringing"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'timeCompletedChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'lengthChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'labelChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'commandTimeoutChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'runningChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'loopingChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'ringingChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'timeUp'
        QtMocHelpers::SlotData<void(int)>(11, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'reschedule'
        QtMocHelpers::SlotData<void()>(13, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'toggleRunning'
        QtMocHelpers::MethodData<void()>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'toggleLooping'
        QtMocHelpers::MethodData<void()>(15, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'reset'
        QtMocHelpers::MethodData<void()>(16, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'elapsed'
        QtMocHelpers::MethodData<int() const>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Method 'uuid'
        QtMocHelpers::MethodData<QString() const>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'timeCompleted'
        QtMocHelpers::MethodData<int() const>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Method 'dismiss'
        QtMocHelpers::MethodData<void()>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'length'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'timeCompleted'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'label'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'commandTimeout'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'running'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'looping'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'ringing'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Timer, qt_meta_tag_ZN5TimerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Timer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5TimerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5TimerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5TimerE_t>.metaTypes,
    nullptr
} };

void Timer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Timer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->timeCompletedChanged(); break;
        case 1: _t->lengthChanged(); break;
        case 2: _t->labelChanged(); break;
        case 3: _t->commandTimeoutChanged(); break;
        case 4: _t->runningChanged(); break;
        case 5: _t->loopingChanged(); break;
        case 6: _t->ringingChanged(); break;
        case 7: _t->timeUp((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->reschedule(); break;
        case 9: _t->toggleRunning(); break;
        case 10: _t->toggleLooping(); break;
        case 11: _t->reset(); break;
        case 12: { int _r = _t->elapsed();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->uuid();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->timeCompleted();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->dismiss(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Timer::*)()>(_a, &Timer::timeCompletedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Timer::*)()>(_a, &Timer::lengthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Timer::*)()>(_a, &Timer::labelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Timer::*)()>(_a, &Timer::commandTimeoutChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Timer::*)()>(_a, &Timer::runningChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Timer::*)()>(_a, &Timer::loopingChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Timer::*)()>(_a, &Timer::ringingChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->length(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->timeCompleted(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->commandTimeout(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->running(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->looping(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->ringing(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLength(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setLabel(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setCommandTimeout(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setLooping(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Timer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Timer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5TimerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Timer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Timer::timeCompletedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Timer::lengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Timer::labelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Timer::commandTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Timer::runningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Timer::loopingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Timer::ringingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
