/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kclockd.AlarmModel.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ALARMMODELINTERFACE_H
#define ALARMMODELINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.kclock.AlarmModel
 */
class OrgKdeKclockAlarmModelInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.kclock.AlarmModel"; }

public:
    OrgKdeKclockAlarmModelInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKclockAlarmModelInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> addAlarm(const QString &name, int hours, int minutes, int daysOfWeek, const QString &audioPath, int ringDuration, int snoozeDuration)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name) << QVariant::fromValue(hours) << QVariant::fromValue(minutes) << QVariant::fromValue(daysOfWeek) << QVariant::fromValue(audioPath) << QVariant::fromValue(ringDuration) << QVariant::fromValue(snoozeDuration);
        return asyncCallWithArgumentList(QStringLiteral("addAlarm"), argumentList);
    }

    inline QDBusPendingReply<qulonglong> getNextAlarm()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("getNextAlarm"), argumentList);
    }

    inline QDBusPendingReply<> removeAlarm(const QString &uuid)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(uuid);
        return asyncCallWithArgumentList(QStringLiteral("removeAlarm"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void alarmAdded(const QString &uuid);
    void alarmRemoved(const QString &uuid);
    void nextAlarm(qulonglong nextAlarmTimeStamp);
};

namespace org {
  namespace kde {
    namespace kclock {
      using AlarmModel = ::OrgKdeKclockAlarmModelInterface;
    }
  }
}

#endif
